@@ -18,6 +18,7 @@ if [ "$db_relations" = "No relations found." ] || \
   "cp ${gitlab_data_dir}/db/schema.rb.template ${gitlab_data_dir}/db/schema.rb"
   runuser -u ${gitlab_user} -- sh -c \
   "touch ${gitlab_data_dir}/.gitlab_shell_secret"
+  runuser -u ${gitlab_user} -- sh -c 'touch /var/lib/gitlab/secrets.yml'
   runuser -u ${gitlab_user} -- sh -c '/usr/bin/bundle exec rake db:schema:load'
 else
   echo "gitlab_production database is not empty, skipping gitlab setup"
@@ -30,9 +31,7 @@ chmod 0700 ${gitlab_data_dir}/.gitlab_shell_secret
 
 echo "Installing node modules..."
 runuser -u ${gitlab_user} -- sh -c 'install -d /var/lib/gitlab/.node_modules'
-runuser -u ${gitlab_user} -- sh -c 'install -d /var/lib/gitlab/yarn'
-runuser -u ${gitlab_user} -- sh -c 'cd /var/lib/gitlab/yarn; npm install yarn'
-runuser -u ${gitlab_user} -- sh -c '/var/lib/gitlab/yarn/node_modules/.bin/yarn --frozen-lockfile install'
+runuser -u ${gitlab_user} -- sh -c 'yarnpkg --frozen-lockfile install'
 # Remove write permissions of .yarn-metadata.json files
 runuser -u ${gitlab_user} -- sh -c 'find /var/lib/gitlab/.cache/yarn/v4/ -name .yarn-metadata.json -perm -a=w -exec chmod 644 {} \;'
 
